package
Version:
v0.0.0-...-1151cc2
Opens a new window with list of versions in this module.
Published: May 20, 2025
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Flags struct {
Force bool
RenameInternalExports bool
IncludeTests bool
OutDir string
KeepNames keepFlag
Seeds seedsFlag
SeedFile string
Debug bool
Verbose bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.